@@ -126,8 +126,11 @@ def clustering_caha_score_by_ncomp(mat, clustermodel, ncompmin=2, ncompmax=20):
     return metrics.calinski_harabasz_score(mat, clustermodel)
 
 
-def censor_data(mat, p=0.0, censored_indices=[], inplace=True, randomgen=None):
+def censor_data(mat, p: float = 0.0, censored_indices: Tuple[int] = [], inplace=True, randomgen=None):
     """
+    Parameters
+    ----------
+    censored_indices : object
 
     """
     assert (0.0 <= p < 1.0)
@@ -194,20 +197,19 @@ def get_observations_km_clusters(mat, ngroups=2):
     return km.fit_predict(mat)
 
 
-def get_clustering_incidence_matrix(mat: Union[np.ndarray, pd.DataFrame],
-                                    df_clust1: Union[np.ndarray, pd.DataFrame, Tuple[int]],
+def get_clustering_incidence_matrix(df_clust1: Union[np.ndarray, pd.DataFrame, Tuple[int]],
                                     df_clust2: Union[np.ndarray, pd.DataFrame, Tuple[int]]):
 
-    assert (len(mat) == len(df_clust1) and len(df_clust1) == len(df_clust2))
+    # assert (len(mat) == len(df_clust1) and len(df_clust1) == len(df_clust2))
+    assert len(df_clust1) == len(df_clust2)
+    nobs = len(df_clust1)
     df_clust1 -= np.min(df_clust1) - 1
     df_clust2 -= np.min(df_clust2) - 1
-    nclust1 = np.max(df_clust1)
-    nclust2 = np.max(df_clust2)
     incidence_mat = pd.DataFrame(index=sorted(pd.unique(df_clust1.iloc[:, 0])),
                                  columns=sorted(pd.unique(df_clust2.iloc[:, 0]))).fillna(0.0, inplace=False)
     df_clust1 = pd.DataFrame(df_clust1)
     df_clust2 = pd.DataFrame(df_clust2)
-    for iobs, obs in enumerate(mat.index):
+    for iobs in range(nobs):
         clust1 = int(df_clust1.iloc[iobs])
         clust2 = int(df_clust2.iloc[iobs])
         incidence_mat.loc[clust1, clust2] = incidence_mat.loc[clust1, clust2] + 1
@@ -215,12 +217,13 @@ def get_clustering_incidence_matrix(mat: Union[np.ndarray, pd.DataFrame],
     return incidence_mat
 
 
-def get_clustering_mismatches(mat: Union[np.ndarray, pd.DataFrame],
-                              df_clust1: Union[np.ndarray, pd.DataFrame, Tuple[int]],
+def get_clustering_mismatches(df_clust1: Union[np.ndarray, pd.DataFrame, Tuple[int]],
                               df_clust2: Union[np.ndarray, pd.DataFrame, Tuple[int]]):
-    inc_mat = get_clustering_incidence_matrix(mat, df_clust1, df_clust2)
+    assert len(df_clust1) == len(df_clust2)
+    nobs = len(df_clust1)
+    inc_mat = get_clustering_incidence_matrix(df_clust1, df_clust2)
     make_diagonal_dominant(inc_mat, inplace=True)
-    nobj = len(mat.index)
+    nobj = len(nobs)
     nmis = nobj - np.trace(inc_mat)
     return nmis, float(nmis) / nobj
 
@@ -228,7 +231,7 @@ def get_clustering_mismatches(mat: Union[np.ndarray, pd.DataFrame],
 def get_nb_misclassifieds_old(mat, grp_priors):
     ngrps = len(set(grp_priors))
     km_grps = get_observations_km_clusters(mat, ngrps)
-    return get_clustering_mismatches(mat, km_grps, grp_priors)
+    return get_clustering_mismatches(km_grps, grp_priors)
 
 
 def get_nb_misclassifieds(mat: Union[np.ndarray, pd.DataFrame],
@@ -323,13 +326,15 @@ def center_by_columns(mat):
     return centered_mat
 
 
-def normalize_by_columns(mat, make_positive: bool = True):
+def normalize_by_columns(mat: Union[np.ndarray, pd.DataFrame],
+                         make_positive: bool = True, add_cst=None, mult_cst=None):
     if type(mat) is not pd.DataFrame:
         cols = list(["F" + str(x) for x in range(1, mat.shape[1] + 1)])
-        mat = pd.DataFrame(data=mat.values, columns=cols)
+        mat = pd.DataFrame(data=mat, columns=cols)
     normalized_mat = mat.copy()
-    add_constants = np.nanmin(normalized_mat, axis=0) if make_positive else np.nanmean(normalized_mat, axis=0)
-    mult_constants = np.nanstd(normalized_mat, axis=0)
+    add_constants = np.nanmin(normalized_mat, axis=0) if make_positive else \
+        add_cst if (add_cst is not None) else np.nanmean(normalized_mat, axis=0)
+    mult_constants = mult_cst if (mult_cst is not None) else np.nanstd(normalized_mat, axis=0)
     normalized_mat -= add_constants
     normalized_mat /= mult_constants
 
