@@ -1,3 +1,4 @@
+import numpy as np
 import pandas as pd
 import adinference
 from adinference import admlp
@@ -26,7 +27,7 @@ if __name__ == "__main__":
     temp_data_path = Path(data_path, fs="local") / "temp_data/"
     pictures_path = Path(data_path, fs="local") / "plot"
     out_data_path = Path(optimal_k_path, fs="local") / "results/"
-    optk_model_dir = Path(models_path, fs="local") / os.getenv("optk_model_dir", "model_MLP_p82")
+    optk_model_dir = os.getenv("optk_model_dir", "model_MLP_p82")
 
     res_path = Path(optimal_k_path, fs="local") / os.getenv("results_subpath")
 
@@ -66,7 +67,12 @@ if __name__ == "__main__":
         preds = my_k_estimator.estimate_ncomp(mat=mat)
     est_do_train_data = True
     if est_do_train_data:
-        train_data = df_train.drop(['Position'], axis="columns", inplace=False)
-        train_data, _, _ = utl.normalize_by_columns(train_data, make_positive=False)
-        train_preds = my_k_estimator.get_predictions(train_data)
+        train_data = df_raw_screeplots.drop(['Position'], axis="columns", inplace=False)
+        # norm_train_data, _, _ = utl.normalize_by_columns(train_data, make_positive=False)
+        norm_train_data = train_data.copy()
+        norm_train_data.loc[:, "Tried_ncomp_0"] = train_data.loc[:, "Tried_ncomp_0"]
+        norm_train_data = norm_train_data.iloc[0:16]
+        ncmin = np.min(norm_train_data.index)
+        ncmax = np.max(norm_train_data.index)-1
+        train_preds = my_k_estimator.estimate_ncomp(df_mini_screeplots=norm_train_data, ncmin=ncmin, ncmax=ncmax)
     pass
