@@ -63,10 +63,10 @@ if __name__ == "__main__":
 
         # Fixer le nombre de composants nmf
         ncomp_brunet = 4
-        nmf_brunet = nmf.NmfModel(mat=df_brunet, name="brunet",
-                                  ncomp=ncomp_brunet, regularization="components", leverage="robust", max_iter=200)
-        nmf_log_brunet = nmf.NmfModel(mat=df_log_brunet, name="log_brunet",
-                                      ncomp=ncomp_brunet, regularization="components", leverage="robust", max_iter=200)
+        nmf_brunet = nmf.NmfModel(mat=df_brunet, ncomp=ncomp_brunet, name="brunet", leverage="robust", max_iter=200,
+                                  regularization="components")
+        nmf_log_brunet = nmf.NmfModel(mat=df_log_brunet, ncomp=ncomp_brunet, name="log_brunet", leverage="robust",
+                                      max_iter=200, regularization="components")
 
 #        sparse_res = tst.test_nmf_sparsity(df_brunet, priors=df_brunet_priors, ncomp=ncomp_brunet, nblocks=1,
 #                                               sp_step=0.1, sp_min=0, sp_max=1,
